@@ -1,4 +1,4 @@
-/* $Id: simple.c 20833 2006-04-09 18:08:17Z benny $ */
+/* $Id: simple.c 21496 2006-05-04 22:12:21Z benny $ */
 /*-
  * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -23,6 +23,10 @@
 #include <config.h>
 #endif
 
+#ifdef XFCE_DISABLE_DEPRECATED
+#undef XFCE_DISABLE_DEPRECATED
+#endif
+
 #include <X11/Xlib.h>
 
 #include <gdk-pixbuf/gdk-pixdata.h>
